<?php
// $Id: civicspace.inc,v 1.13 2006/06/02 06:53:10 webchick Exp $

/*
 * The administration menu config has three basic pieces. 'section' which
 * are separate because they need their own menu entries, 'menu'
 * which need to be individually reconfigured, and 'alias' items in
 * case we want to alias menu items around.
 *
 * Each section entry has:
 * 'title' => The short title
 * 'description' => The longer descriptive title
 * 'callback' => The callback to use for this section. If blank no menu entry
 *               will be provided.
 *
 * Each menu entry has
 *  'title' => The short title of the menu entry
 *  'description' => The longer desc
 *  'weight' => A weight can be specified; this will override the default weight
 *              and is not recommended; the default weight will put menu items
 *              in the order they appear in the array.
 */
function _administration_menu_config() {
  $config['cssfile'] = 'civicspace.css';
  $config['default']['sub_panel_theme'] = 'cs_administration_sub_menu_panel';

  // This is for new links so that they get the right permissions.
  // Kind of annoying honestly.

  $config['section']['sadmin/features'] = array(
    'title'       => t('features'),
    'description' => t('New Features and Applications'),
    'long-desc'   => t("You can configure new applications, known as modules, and learn how to add new features."),
    'callback'    => '_administration_sub_dashboard_page',
    'panel_theme' => 'cs_administration_menu_panel',
    'sub_panel_theme' => 'cs_administration_sub_menu_panel',
    'sub_panel_css' => 'dashboard',
    'items' => array(
      'admin/help' => array(
        'title' => 'help',
        'description' => 'Application (Module) help',
        'class' => 'dashboard-help',
      ),
      'sadmin/features/support' => array(
        'title' => 'get support',
        'description' => 'Get support',
        'short-desc' => 'A page that explains support options, including paid support',
        'long-desc' => 'This exists as an example of what the long-desc will do',
        'callback' => 'administration_offsite',
        'callback arguments' => array('http://drupal.org/support'),
        'class' => 'dashboard-help',
      ),
      'admin/modules' => array(
        'title' => 'activate/deactivate',
        'description' => 'Turn on and off applications (modules)',
        'class' => 'dashboard-admin',
      ),
      'sadmin/modules' => array(
        'title' => 'configure modules',
        'description' => "Configure my site's application (module) settings",
        'callback'    => '_administration_sub_dashboard_page',
        'class' => 'dashboard-admin',
      ),
      'sadmin/style/no-link1' => array(
        'title' => 'troubleshoot your theme',
        'description' => 'Troubleshoot your theme',
        'short-desc' => 'Help page that describes best practices for troubleshooting',
        'callback' => 'administration_offsite',
        'callback arguments' => array('http://drupal.org/node/37156'),
        'class' => 'dashboard-help',
      ),
      'sadmin/features/no-link1' => array(
        'title' => t('Application categories'),
        'description' => t('Review new features and applications'),
        'short-desc' => t('Administration, Categories, Commerce/advertising, Community, Content, Content display, Evaluation/rating, Event, File management, Mail, Media, Paging, Security, Theme,User access/authentication, Utility'),
        'callback' => 'administration_offsite',
        'callback arguments' => array('http://drupal.org/project/Modules/category'),
        'class' => 'dashboard-help',
      ),
    ),
  );

  $config['section']['sadmin/content'] = array(
    'title'       => t('content'),
    'description' => t('Manage web pages (content)'),
    'long-desc'   => t('Web pages are treated as content that can be managed with settings'),
    'callback'    => '_administration_sub_dashboard_page',
    'panel_theme' => 'cs_administration_menu_panel',
    'sub_panel_theme' => 'cs_administration_sub_menu_panel',
    'sub_panel_css' => 'dashboard',
    'items' => array(
      'admin/comment' => array(
        'title' => 'manage comments',
        'description' => "Moderate and publish comments",
        'class' => 'dashboard-admin',
      ),
      'admin/node' => array(
        'title' => 'manage content',
        'description' => "Moderate, promote and manage your web pages",
        'class' => 'dashboard-admin',
      ),
      'admin/taxonomy' => array(
        'title' => 'manage categories',
        'description' => "Set up and maintain your site's categories (vocabularies/taxonomy)",
        'class' => 'dashboard-admin',
      ),
      'admin/node' => array(
        'title' => 'organize',
        'description' => 'Order and organize web pages (content)',
        'class' => 'dashboard-admin',
      ),
    ),
  );

  $config['section']['sadmin/build'] = array(
    'title'       => t('build'),
    'description' => t('Build your web site'),
    'long-desc'   => t('Administering role permissions, installing new applications, upgrading, configuring menus'),
    'callback'    => '_administration_sub_dashboard_page',
    'panel_theme' => 'cs_administration_menu_panel',
    'sub_panel_theme' => 'cs_administration_sub_menu_panel',
    'sub_panel_css' => 'dashboard',
    'items' => array(
      'sadmin/build/no-link2' => array(
        'title' => 'install new modules (applications)',
        'description' => 'Install new applications (modules)',
        'short-desc' => 'Help instructions to download application (module) files',
        'callback' => 'administration_offsite',
        'callback arguments' => array('http://drupal.org/node/17473'),
        'class' => 'dashboard-help',
      ),
      'sadmin/build/no-link1' => array(
        'title' => 'upgrade site',
        'description' => 'Instructions for upgrading your site',
        'short-desc' => 'Upgrading CivicSpace, CiviCRM, database, individual modules',
        'callback' => 'administration_offsite',
        'callback arguments' => array('http://civicspacelabs.org/home/upgrade'),
        'class' => 'dashboard-help',
      ),
      'admin/menu' => array(
        'title' => 'menus',
        'description' => "Create and configure menus",
        'short-desc' => "Rename menu links to be friendly to your users",
        'class' => 'dashboard-admin',
      ),
      'admin/filters' => array(
        'title' => 'input formats',
        'description' => "Configure allowable input formats/input filters",
        'short-desc' => 'Configure allowable input formats/input filters such as HTML, PHP',
        'class' => 'dashboard-admin',
      ),
      'admin/access' => array(
        'title' => 'role access control',
        'description' => "Configure user role permissions",
        'short-desc' => "permissions for admins, editors, volunteers, anonymous, registered users",
        'class' => 'dashboard-admin',
      ),
      'admin/path' => array(
        'title' => 'url aliases',
        'description' => "Create and manage URL aliases",
        'short-desc'=>'Readable URLs help users and search engines',
        'class' => 'dashboard-admin',
      ),
    ),
  );

  $config['section']['sadmin/style'] = array(
    'title'       => t('style'),
    'description' => t('Style and layout'),
    'long-desc'   => t('Administering style and layout elements of your web site'),
    'callback'    => '_administration_sub_dashboard_page',
    'panel_theme' => 'cs_administration_menu_panel',
    'sub_panel_theme' => 'cs_administration_sub_menu_panel',
    'sub_panel_css' => 'dashboard',
    'items' => array(
      'admin/themes' => array(
        'title' => 'themes',
        'description' => "Activate/configure themes",
        'class' => 'dashboard-admin',
      ),
      'admin/block' => array(
        'title' => 'blocks',
        'description' => "Activate/configure blocks",
        'short-desc' => "Configure blocks for users, pages, and webpage type",
        'class' => 'dashboard-admin',
      ),
      'admin/settings/front_page' => array(
        'title' => 'front page',
        'description' => "Design front page",
        'short-desc' => "Design front page for anonymous, authenticated users",
        'class' => 'dashboard-admin',
      ),
      'sadmin/style/no-link1' => array(
        'title' => 'troubleshoot your theme',
        'description' => 'Troubleshoot your theme',
        'short-desc' => 'Help page that describes best practices for troubleshooting',
        'callback' => 'administration_offsite',
        'callback arguments' => array('http://drupal.org/node/37156'),
        'class' => 'dashboard-help',
      ),
	  'sadmin/build/no-link3' => array(
        'title' => 'Block examples',
        'description' => 'Block examples',
        'short-desc' => 'Sample PHP for making custom blocks',
        'callback' => 'administration_offsite',
        'callback arguments' => array('http://drupal.org/node/21867'),
        'class' => 'dashboard-help',
      ),
      'sadmin/style/no-link2' => array(
        'title' => 'page layout',
        'description' => 'Page layout',
        'short-desc' => 'Advanced PHP examples for modifying page layouts, front pages, number of columns',
        'callback' => 'administration_offsite',
        'callback arguments' => array('http://drupal.org/node/46006'),
        'class' => 'dashboard-help',
      ),
    ),
  );

  $config['section']['sadmin/overview'] = array(
    'title'       => t('manage web site and users'),
    'description' => t('Manage web site and users'),
    'long-desc'   => t('Manage web site settings, view system logs, manage users'),
    'callback'    => '_administration_sub_dashboard_page',
    'panel_theme' => 'cs_administration_menu_panel',
    'sub_panel_theme' => 'cs_administration_sub_menu_panel',
    'sub_panel_css' => 'dashboard',
    'items' => array(
      'admin/user' => array(
        'title' => 'manage users',
        'description' => "Change or add users",
        'class' => 'dashboard-admin',
      ),
       'admin/settings' => array(
         'title'       => t('site settings'),
         'description' => t('Configure site-wide settings'),
         'short-desc' => 'General settings, error handling, cache, and time zone settings',
         'callback'    => 'system_site_settings',
         'class' => 'dashboard-admin',
      ),
      'civicrm' => array(
        'title' => 'civicrm',
        'description' => "CiviCRM",
        'short-desc' => 'manage contact information, contact relationships, and contact activity history',
        'class' => 'dashboard-admin',
      ),
      'admin/logs' => array(
        'title' => 'logs',
        'description' => "Site errors and other logs",
        'class' => 'dashboard-admin',
      ),
    ),
  );

  $config['section']['sadmin/mail'] = array(
    'title'       => t('mail'),
    'description' => t('Mail and Subscriptions'),
    'long-desc'   => t('Manage mail, compose newsletters, subscription management'),
    'callback'    => '_administration_sub_dashboard_page',
    'panel_theme' => 'cs_administration_menu_panel',
    'sub_panel_theme' => 'cs_administration_sub_menu_panel',
    'sub_panel_css' => 'dashboard',
    'items' => array(
      'admin/massmailer/list' => array(
        'title' => 'mailing lists',
        'description' => 'Mailing lists',
        'class' => 'dashboard-admin',
      ),
      'admin/aggregator' => array(
        'title' => 'news feeds',
        'description' => "Manage my news feeds",
        'class' => 'dashboard-admin',
      ),
    ),
  );

  /* webchick: commenting this out; this now appears in the "Manage web site and users" section
  $config['section']['sadmin/statistics'] = array(
    'title'       => t('statistics'),
    'description' => t('Site Statistics'),
    'long-desc'   => t('A glance at administrative statistics about your site'),
    'callback'    => '_administration_sub_dashboard_page',
    'panel_theme' => 'administration_statistics',
    'sub_panel_css' => 'dashboard',
    'class' => 'dashboard-admin',
  ); */

  // This special one clones the system settings section so it goes into the
  // right place
  /* FARSHEED: moved this into 'Build your website' section for consistency.
  $config['section']['sadmin/build/settings'] = array(
    'title'       => t('site settings'),
    'description' => t('Configure site-wide settings'),
    'callback'    => 'system_site_settings',
    'class' => 'dashboard-admin',
  );
  */

  // overrides to repoint a couple of settings.
  /*
  $config['section']['sadmin/settings'] = array(
    'title' => t('configure applications'),
    'description' => t("Configure my site's application (module) settings"),
    'callback'    => '_administration_settings_page',
    'class' => 'dashboard-admin',
  );

  // overrides to repoint a couple of settings.
  $config['section']['sadmin'] = array(
    'title' => t('configure modules'),
    'description' => t("Configure uncategorized module settings"),
    'callback'    => '_administration_sub_dashboard_page',
    'class' => 'dashboard-admin',
  );
  /**/

  $config['dashboard']['dashboard'] = array(
    'sadmin/features',
    'sadmin/content',
    'sadmin/build',
    'sadmin/style',
    'sadmin/overview',
    'sadmin/mail',
  );

  return $config;
}

function theme_cs_administration_menu_panel($path) {
  static $old_class;
  // Just a copy of the standard one, but uses 2 columns.

  $config = _administration_menu_config();
  $menu = menu_get_menu();
  $mid = $menu['path index'][$path];

  // Grab the title to generate a unique ID for each grouping
  $title = $menu['items'][$mid]['title'];
  // We only want the first word; no spaces in IDs
  if ($space = strpos($title, ' ')) {
    $title = substr($title, 0, $space);
  }

  $output = "  <!-- START administration menu panel -->\n";
  $output .= "  <div class=\"dashboard-panel\" id=\"". $title ."\">\n";
  $output .= "    <div class=\"dashboard-panel-head\">" . $menu['items'][$mid]['description'] . "</div>\n";
  $output .= "    <div class=\"dashboard-panel-body\">\n";
  $output .= "      <div class=\"dashboard-panel-desc\">". $config['section'][$path]['long-desc'] . "</div>\n";
  $output .= "        <!-- START dashboards-wrapper -->\n";
  $output .= "        <div class=\"wrapper\">\n";
  $counter = 0;
  if (!isset($menu['visible'][$mid]['children']) || !is_array($menu['visible'][$mid]['children'])) {
    // Menus are deactivated; re-direct to admin
    drupal_goto('admin');
  }
  foreach ($menu['visible'][$mid]['children'] as $cid) {
    $item = '                    <li>';
    $title = !empty($menu['items'][$cid]['description']) ? $menu['items'][$cid]['description'] : $menu['items'][$cid]['title'];
    $item .= l($title, $menu['items'][$cid]['path'], array('title' => $menu['items'][$cid]['title']));
    if (isset($config['section'][$path]['items'][$menu['items'][$cid]['path']]['short-desc'])) {
      $longdesc = $config['section'][$path]['items'][$menu['items'][$cid]['path']]['short-desc'];
      $item .= "<div class=\"desc\"> $longdesc </div>";
    }
    $class = $config['section'][$path]['items'][$menu['items'][$cid]['path']]['class'];
    $item .= "</li>\n";
    if (!isset($group[$class])) {
      $group[$class] = $item;
    }
    else {
      $group[$class] .= $item;
    }
  }
  krsort($group);
  foreach($group as $class => $text) {
    // Show statistics panel under "Manage web site and users"
    // This goes before the 'normal' panel due to the way the CSS
    // is setup.
    if ($path == 'sadmin/overview') {
      $output .= theme('cs_administration_statistics');
    }
    if (!$class) $class = 'dashboard-admin';
    $output   .= "          <!-- START box -->\n";
    $output   .= "          <div class=\"$class\"><div class=\"$class-buffer\">\n";
    $output   .= "            <div class=\"xsnazzy\">\n";
    $output   .= "              <b class=\"xtop\"><b class=\"xb1\"></b><b class=\"xb2\"></b><b class=\"xb3\"></b><b class=\"xb4\"></b></b>\n";
    $output   .= "                <div class=\"xboxcontent\">\n";
    $output   .= "                  <ul>\n";
    $output   .= $text;
    $output   .= "                  </ul>\n";
    $output   .= "                </div>\n";
    $output   .= "              <b class=\"xbottom\"><b class=\"xb4\"></b><b class=\"xb3\"></b><b class=\"xb2\"></b><b class=\"xb1\"></b></b>\n";
    $output   .= "            </div>\n";
    $output   .= "          </div></div>\n";
    $output   .= "          <!-- END box -->\n";
  }
  $output     .= "        </div>\n";
  $output     .= "        <!-- END dashboards-wrapper -->\n";
  $output     .= "      </div>\n";
  $output     .= "    </div>\n";
  $output     .= "    <!-- END administration menu panel -->\n";
  return $output;
}

function theme_cs_administration_sub_menu_panel() {
  drupal_set_title('');
  $config = _administration_menu_config();
  $menu = menu_get_menu();
  $mid = menu_get_active_item();
  $path = $menu['items'][$mid]['path'];

  // Grab the title to generate a unique ID for each grouping
  $title = $menu['items'][$mid]['title'];
  // We only want the first word; no spaces in IDs
  if ($space = strpos($title, ' ')) {
    $title = substr($title, 0, $space);
  }

  // START copy from theme_cs_administration_menu_panel
  $output .= "  <!-- START administration menu panel -->\n";
  $output .= "  <div class=\"dashboard-panel\" id=\"". $title ."\">\n";
  $output .= "    <div class=\"dashboard-panel-head\">" . $menu['items'][$mid]['description'] . "</div>\n";
  $output .= "    <div class=\"dashboard-panel-body\">\n";
  $output .= "      <div class=\"dashboard-panel-desc\">". $config['section'][$path]['long-desc'] . "</div>\n";
  $output .= "        <!-- START dashboards-wrapper -->\n";
  $output .= "        <div class=\"wrapper\">\n";;
  $output   .= "          <div class=\"dashboard-admin\"><div class=\"dashboard-admin-buffer\">\n";
  $output   .= "            <div class=\"xsnazzy\">\n";
  $output   .= "              <b class=\"xtop\"><b class=\"xb1\"></b><b class=\"xb2\"></b><b class=\"xb3\"></b><b class=\"xb4\"></b></b>\n";
  $output   .= "                <div class=\"xboxcontent\">\n";
  // END copy from theme_cs_administration_menu_panel
  $output .= "      <ul>\n";
  foreach ($menu['visible'][$mid]['children'] as $cid) {
    $output .= '        <li>';
    $title = !empty($menu['items'][$cid]['description']) ? $menu['items'][$cid]['description'] : $menu['items'][$cid]['title'];
    $output .= l($title, $menu['items'][$cid]['path'], array('title' => $menu['items'][$cid]['title']));
    $longdesc = $config['section'][$path]['items'][$menu['items'][$cid]['path']]['long-desc'];
    if ($longdesc) {
      $output .= " $longdesc";
    }
    $output .= "</li>\n";
  }
  $output .= "      </ul>\n";
  // START copy from theme_cs_administration_menu_panel
  $output   .= "                </div>\n";
  $output   .= "              <b class=\"xbottom\"><b class=\"xb4\"></b><b class=\"xb3\"></b><b class=\"xb2\"></b><b class=\"xb1\"></b></b>\n";
  $output   .= "            </div>\n";
  $output   .= "          </div></div>\n";
  $output   .= "          <!-- END box -->\n";
  $output     .= "        </div>\n";
  $output     .= "        <!-- END dashboards-wrapper -->\n";
  $output     .= "      </div>\n";
  $output     .= "    </div>\n";
  $output     .= "    <!-- END administration menu panel -->\n";
  // END copy from theme_cs_administration_menu_panel
  return $output;
}

function theme_administration_statistics_panel($stats, $path = NULL) {
  $config = _administration_menu_config();
  $menu = menu_get_menu();
  if (!$path) {
    $mid = menu_get_active_item();
    $path = $menu['items'][$mid]['path'];
  }
  else {
    $mid = $menu['path index'][$path];
  }
  $output = "      <h2>Site Statistics</h2>\n";
  $output .= "      <ul>\n";
  $counter = 0;
  $last = count($stats);
  foreach ($stats as $stat) {
    $output .= "          <div class=\"stats-li-wrapper\"><li><span 
class=\"stat-title\">{$stat['title']}</span>: <span 
class=\"stat-value\">{$stat['value']}</span></li></div>\n";
/*    if ($counter++ % 2 == 1 || $counter == $last) {
      $output .= "       <tr>\n";
      $output .= $item;
      $output .= "       </tr>\n";
      $item = "";
    }*/
  }
  $output .= "      </ul>\n";
  return $output;

}

/**
 * Formats statistics for display inside a panel.
 */
function theme_cs_administration_statistics() {
  $class = 'dashboard-stats';
  $output   = "          <!-- START box -->\n";
  $output   .= "          <div class=\"$class\"><div class=\"$class-buffer\">\n";
  $output   .= "            <div class=\"xsnazzy\">\n";
  $output   .= "              <b class=\"xtop\"><b class=\"xb1\"></b><b class=\"xb2\"></b><b class=\"xb3\"></b><b class=\"xb4\"></b></b>\n";
  $output   .= "                <div class=\"xboxcontent\">\n";
  $output   .= theme('administration_statistics_panel', cs_administration_statistics());
  $output   .= "                </div>\n";
  $output   .= "              <b class=\"xbottom\"><b class=\"xb4\"></b><b class=\"xb3\"></b><b class=\"xb2\"></b><b class=\"xb1\"></b></b>\n";
  $output   .= "            </div>\n";
  $output   .= "          </div></div>\n";
  $output   .= "          <!-- END box -->\n";
  return $output;
}

/**
 * Retrieves statistics into an array
 */
function cs_administration_statistics() {
  $users = db_result(db_query("SELECT COUNT(*) FROM {users} WHERE status = 1"));
  $stats['users'] = array('title' => "Users", 'value' => $users);

  $nodes = db_result(db_query("SELECT COUNT(*) FROM {node} WHERE status = 1"));
  $stats['nodes'] = array('title' => "Published web pages", 'value' => $nodes);

  $comments = db_result(db_query("SELECT COUNT(*) FROM {comments} WHERE status = 0"));
  $stats['comments'] = array('title' => "Published comments", 'value' => $comments);

  if (function_exists('memory_get_usage')) {
    $memory_used = memory_get_usage();
    $stats['memory'] = array(
      'title' => t('Memory used'),
      'value' => t('%value MB', array('%value' => round($memory_used / 1024 / 1024, 2)))
    );
  }

  return $stats;
}
